; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional)
;   buffer.time = time (optional)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas. Each of these
;   buttons or directions is referred to as a "symbol".
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine the symbols:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;
;   Note: Successive direction symbols are always expanded in a manner similar
;         to this example:
;           command = F, F
;         is expanded when MUGEN reads it, to become equivalent to:
;           command = F, >~F, >F
;
;   It is recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This makes the command easier
;   to do.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. The default
;   value for this is set in the [Defaults] section below. A typical
;   value is 15.
;
; - buffer.time (optional)
;   Time that the command will be buffered for. If the command is done
;   successfully, then it will be valid for this time. The simplest
;   case is to set this to 1. That means that the command is valid
;   only in the same tick it is performed. With a higher value, such
;   as 3 or 4, you can get a "looser" feel to the command. The result
;   is that combos can become easier to do because you can perform
;   the command early. Attacks just as you regain control (eg. from
;   getting up) also become easier to do. The side effect of this is
;   that the command is continuously asserted, so it will seem as if
;   you had performed the move rapidly in succession during the valid
;   time. To understand this, try setting buffer.time to 30 and hit
;   a fast attack, such as KFM's light punch.
;   The default value for this is set in the [Defaults] section below. 
;   This parameter does not affect hold-only commands (eg. /F). It
;   will be assumed to be 1 for those commands.
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10


;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 15

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1


;-| AI |-----------------------------------------------------------

[Command]
name = "AI-000"
command = ~F,a,~D,y,~U,c+x,D,b+y,F,z,z,z+a
time = 1

[Command]
name = "AI-001"
command = ~F,c,~D,y,~U,c+a,D,b+x,B,z,z,z+b
time = 1

[Command]
name = "AI-002"
command = ~F,y,~D,y,~U,c+y,D,b+z,F,z,z,z+c
time = 1

[Command]
name = "AI-003"
command = ~F,b,~D,y,~U,c+b,D,b+a,B,z,z,z+x
time = 1

[Command]
name = "AI-004"
command = ~F,x,~D,x,~U,c+x,D,b+y,F,z,z,z+y
time = 1

[Command]
name = "AI-005"
command = ~F,z,~D,y,~U,c+a,D,b+c,B,z,z,z+a
time = 1

[Command]
name = "AI-006"
command = ~D,U,x+y+z,~F,F,b,c,y,B,~B,a+b+c,U
time = 1

[Command]
name = "AI-007"
command = ~U,D,x+b+z,~F,F,b,b,x,B,~B,a+y+c,F
time = 1

[Command]
name = "AI-008"
command = ~D,U,a+y+c,~F,F,b,a,z,B,~B,x+b+z,D
time = 1

[Command]
name = "AI-009"
command = ~U,D,x+b+c,~F,F,b,c,x,B,~B,a+y+z,B
time = 1

[Command]
name = "AI-010"
command = ~x,~y,~z,~a,~b,~c,~s,a+b+c,x+y+z,~F,B
time = 1

[Command]
name = "AI-011"
command = F,D,F
time = 0

[Command]
name = "AI-012"
command = B,F,B
time = 0

[Command]
name = "AI-013"
command = U,B,U
time = 0

[Command]
name = "AI-014"
command = D,U,D
time = 0

[Command]
name = "AI-015"
command = a,s,a
time = 0

[Command]
name = "AI-016"
command = b,a,b
time = 0

[Command]
name = "AI-017"
command = c,b,c
time = 0

[Command]
name = "AI-018"
command = x,c,x
time = 0

[Command]
name = "AI-019"
command = y,x,y
time = 0

[Command]
name = "AI-020"
command = z,y,z
time = 0

[Command]
name = "AI-021"
command = a,b,x,c
time = 0

[Command]
name = "AI-022"
command = a,b,x,c,a,z,a,z,a,a,a
time = 0

[Command]
name = "AI-023"
command = a,b,x,c,a,z,a,z,a,a
time = 0

[Command]
name = "AI-024"
command = a,b,x,c,a,z,a,z,z
time = 0

[Command]
name = "AI-025"
command = a,b,x,c,a,z,a,z,y
time = 0

[Command]
name = "AI-026"
command = a,b,x,c,a,z,a,z,x
time = 0

[Command]
name = "AI-027"
command = a,b,x,c,a,z,a,z,s
time = 0

[Command]
name = "AI-028"
command = a,b,x,c,a,z,a,z,c
time = 0

[Command]
name = "AI-029"
command = a,b,x,c,a,z,a,z,b
time = 0

[Command]
name = "AI-030"
command = a,b,x,c,a,z,a,z,a
time = 0

[Command]
name = "AI-031"
command = a,b,x,c,a,z,a,z
time = 0

[Command]
name = "AI-032"
command = a,b,x,c,a,z,a,y
time = 0

[Command]
name = "AI-033"
command = a,b,x,c,a,z,a,x
time = 1

[Command]
name = "AI-034"
command = a,b,x,c,a,z,a,c
time = 1

[Command]
name = "AI-035"
command = a,b,x,c,a,z,a,s
time = 1

[Command]
name = "AI-036"
command = a,b,x,c,a,z,a,b,a
time = 1

[Command]
name = "AI-037"
command = a,b,x,c,a,z,a,b
time = 1

[Command]
name = "AI-038"
command = a,b,x,c,a,z,a
time = 1

[Command]
name = "AI-039"
command = a,b,x,c,a,z
time = 1

[Command]
name = "AI-040"
command = a,b,x,c,a
time = 1

[Command]
name = "AI-041"
command = a,b,x,c,y
time = 1

[Command]
name = "AI-042"
command = z,z,z,z,z,z,z,z,y,~F,a,~D,y,~U,c+x,D,b+y,F,z,z,z+a
time = 1

[Command]
name = "AI-043"
command = z,z,z,z,z,z,z,z,y,~F,c,~D,y,~U,c+a,D,b+x,B,z,z,z+b
time = 1

[Command]
name = "AI-044"
command = z,z,z,z,z,z,z,z,y,~F,y,~D,y,~U,c+y,D,b+z,F,z,z,z+c
time = 1

[Command]
name = "AI-045"
command = z,z,z,z,z,z,z,z,y,~F,b,~D,y,~U,c+b,D,b+a,B,z,z,z+x
time = 1

[Command]
name = "AI-046"
command = z,z,z,z,z,z,z,z,y,~F,x,~D,x,~U,c+x,D,b+y,F,z,z,z+y
time = 1

[Command]
name = "AI-047"
command = z,z,z,z,z,z,z,z,y,~F,z,~D,y,~U,c+a,D,b+c,B,z,z,z+a
time = 1

[Command]
name = "AI-048"
command = z,z,z,z,z,z,z,z,y,~D,U,x+y+z,~F,F,b,c,y,B,~B,a+b+c,U
time = 1

[Command]
name = "AI-049"
command = z,z,z,z,z,z,z,z,y,~U,D,x+b+z,~F,F,b,b,x,B,~B,a+y+c,F
time = 1

[Command]
name = "AI-050"
command = z,z,z,z,z,z,z,z,y,~D,U,a+y+c,~F,F,b,a,z,B,~B,x+b+z,D
time = 1

[Command]
name = "AI-051"
command = z,z,z,z,z,z,z,z,y,~U,D,x+b+c,~F,F,b,c,x,B,~B,a+y+z,B
time = 1

[Command]
name = "AI-052"
command = z,z,z,z,z,z,z,z,y,~x,~y,~z,~a,~b,~c,~s,a+b+c,x+y+z,~F,B
time = 1

[Command]
name = "AI-053"
command = z,z,z,z,z,z,z,z,y,F,D,F
time = 0

[Command]
name = "AI-054"
command = z,z,z,z,z,z,z,z,y,B,F,B
time = 0

[Command]
name = "AI-055"
command = z,z,z,z,z,z,z,z,y,U,B,U
time = 0

[Command]
name = "AI-056"
command = z,z,z,z,z,z,z,z,y,D,U,D
time = 0

[Command]
name = "AI-057"
command = z,z,z,z,z,z,z,z,y,a,s,a
time = 0

[Command]
name = "AI-058"
command = z,z,z,z,z,z,z,z,y,b,a,b
time = 0

[Command]
name = "AI-059"
command = z,z,z,z,z,z,z,z,y,c,b,c
time = 0

[Command]
name = "AI-060"
command = z,z,z,z,z,z,z,z,y,x,c,x
time = 0

[Command]
name = "AI-061"
command = z,z,z,z,z,z,z,z,y,y,x,y
time = 0

[Command]
name = "AI-062"
command = z,z,z,z,z,z,z,z,y,z,y,z
time = 0

[Command]
name = "AI-063"
command = z,z,z,z,z,z,z,z,y,a,b,x,c
time = 0

[Command]
name = "AI-064"
command = z,z,z,z,z,z,z,z,y,a,b,x,c,a,z,a,z,a,a,a
time = 0

[Command]
name = "AI-065"
command = z,z,z,z,z,z,z,z,y,a,b,x,c,a,z,a,z,a,a
time = 0

[Command]
name = "AI-066"
command = z,z,z,z,z,z,z,z,y,a,b,x,c,a,z,a,z,z
time = 0

[Command]
name = "AI-067"
command = z,z,z,z,z,z,z,z,y,a,b,x,c,a,z,a,z,y
time = 0

[Command]
name = "AI-068"
command = z,z,z,z,z,z,z,z,y,a,b,x,c,a,z,a,z,x
time = 0

[Command]
name = "AI-069"
command = z,z,z,z,z,z,z,z,y,a,b,x,c,a,z,a,z,s
time = 0

[Command]
name = "AI-070"
command = z,z,z,z,z,z,z,z,y,a,b,x,c,a,z,a,z,c
time = 0

[Command]
name = "AI-071"
command = z,z,z,z,z,z,z,z,y,a,b,x,c,a,z,a,z,b
time = 0

[Command]
name = "AI-072"
command = z,z,z,z,z,z,z,z,y,a,b,x,c,a,z,a,z,a
time = 0

[Command]
name = "AI-073"
command = z,z,z,z,z,z,z,z,y,a,b,x,c,a,z,a,z
time = 0

[Command]
name = "AI-074"
command = z,z,z,z,z,z,z,z,y,a,b,x,c,a,z,a,y
time = 0

[Command]
name = "AI-075"
command = z,z,z,z,z,z,z,z,y,a,b,x,c,a,z,a,x
time = 1

[Command]
name = "AI-076"
command = z,z,z,z,z,z,z,z,y,a,b,x,c,a,z,a,c
time = 1

[Command]
name = "AI-077"
command = z,z,z,z,z,z,z,z,y,a,b,x,c,a,z,a,s
time = 1

[Command]
name = "AI-078"
command = z,z,z,z,z,z,z,z,y,a,b,x,c,a,z,a,b,a
time = 1

[Command]
name = "AI-079"
command = z,z,z,z,z,z,z,z,y,a,b,x,c,a,z,a,b
time = 1

[Command]
name = "AI-080"
command = z,z,z,z,z,z,z,z,y,a,b,x,c,a,z,a
time = 1

[Command]
name = "AI-081"
command = z,z,z,z,z,z,z,z,y,a,b,x,c,a,z
time = 1

[Command]
name = "AI-082"
command = z,z,z,z,z,z,z,z,y,a,b,x,c,a
time = 1

[Command]
name = "AI-083"
command = z,z,z,z,z,z,z,z,y,a,b,x,c,y
time = 1

[Command]
name = "AI-084"
command = z,z,z,z,z,z,z,z,y,z,z,z,z,z,z,z,z,y,a,b,x,c,a,z,a,z,a,a,a
time = 0

[Command]
name = "AI-085"
command = z,z,z,z,z,z,z,z,y,z,z,z,z,z,z,z,z,y,a,b,x,c,a,z,a,z,a,a
time = 0

[Command]
name = "AI-086"
command = z,z,z,z,z,z,z,z,y,z,z,z,z,z,z,z,z,y,a,b,x,c,a,z,a,z,z
time = 0

[Command]
name = "AI-087"
command = z,z,z,z,z,z,z,z,y,z,z,z,z,z,z,z,z,y,a,b,x,c,a,z,a,z,y
time = 0

[Command]
name = "AI-088"
command = z,z,z,z,z,z,z,z,y,z,z,z,z,z,z,z,z,y,a,b,x,c,a,z,a,z,x
time = 0

[Command]
name = "AI-089"
command = z,z,z,z,z,z,z,z,y,z,z,z,z,z,z,z,z,y,a,b,x,c,a,z,a,z,s
time = 0

[Command]
name = "AI-090"
command = z,z,z,z,z,z,z,z,y,z,z,z,z,z,z,z,z,y,a,b,x,c,a,z,a,z,c
time = 0

[Command]
name = "AI-091"
command = z,z,z,z,z,z,z,z,y,z,z,z,z,z,z,z,z,y,a,b,x,c,a,z,a,z,b
time = 0

[Command]
name = "AI-092"
command = z,z,z,z,z,z,z,z,y,z,z,z,z,z,z,z,z,y,a,b,x,c,a,z,a,z,a
time = 0

[Command]
name = "AI-093"
command = z,z,z,z,z,z,z,z,y,z,z,z,z,z,z,z,z,y,a,b,x,c,a,z,a,z
time = 0

[Command]
name = "AI-094"
command = z,z,z,z,z,z,z,z,y,z,z,z,z,z,z,z,z,y,a,b,x,c,a,z,a,y
time = 0

[Command]
name = "AI-095"
command = z,z,z,z,z,z,z,z,y,z,z,z,z,z,z,z,z,y,a,b,x,c,a,z,a,x
time = 1

[Command]
name = "AI-096"
command = z,z,z,z,z,z,z,z,y,z,z,z,z,z,z,z,z,y,a,b,x,c,a,z,a,c
time = 1

[Command]
name = "AI-097"
command = z,z,z,z,z,z,z,z,y,z,z,z,z,z,z,z,z,y,a,b,x,c,a,z,a,s
time = 1

[Command]
name = "AI-098"
command = z,z,z,z,z,z,z,z,y,z,z,z,z,z,z,z,z,y,a,b,x,c,a,z,a,b,a
time = 1

[Command]
name = "AI-099"
command = z,z,z,z,z,z,z,z,y,z,z,z,z,z,z,z,z,y,a,b,x,c,a,z,a,b
time = 1

;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;

;-| Special Motions |------------------------------------------------------

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

[Command]
name = "holdstart"
command = /$s
time = 1

[Command]
name = "DU";Required (do not remove)
command = U
time = 60

[Command]
name = "FF";Required (do not remove)
command = F, F
time = 1

;(up[߁vpɃR}hǉĂ܂)
[Command]
name = "hold_c"
command = /c

;-| command+command |--------------------------------------------------------------
[Command]
name = "ab"
command = a+b
time = 1


;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;==AIpXe[g=========================================================================

;---------------------------------------------------------------------------
;KE

[State \[[Jm]
type = ChangeState
value = 1000
triggerall = Random < 2147483647
triggerall = ctrl && (var(30)=30)
triggerall = power >= 3000
triggerAll = statetype != A
triggerAll = ctrl
trigger1 = 1

[State ]
type = ChangeState
value = 1011
triggerall = Random < 2147483647
triggerall = ctrl && (var(30)=30)
triggerall = power = [2000,2999]
triggerAll = statetype != A
triggerAll = ctrl
trigger1 = Random < 200
trigger2 = Life < 1100

[State 啬]
type = ChangeState
value = 1010
triggerall = Random < 2147483647
triggerall = ctrl && (var(30)=30)
triggerall = power = [1000,1999]
triggerAll = statetype != A
triggerAll = ctrl
trigger1 = Random < 200
trigger2 = Life < 1100

;---------------------------------------------------------------------------
;L͈

[State nk]
type = ChangeState
value = 230
triggerall = Random < 2147483647
triggerall = Random < 100
triggerall = ctrl && (var(30)=30)
trigger1 = statetype != A
trigger1 = P2statetype != A
trigger1 = P2statetype != L
trigger1 = ctrl

[State tA]
type = ChangeState
value = 253
triggerall = Random < 2147483647
triggerall = Random < 100
triggerall = ctrl && (var(30)=30)
triggerall = numhelper(254) = 0
triggerall = statetype != A
triggerall = ctrl
trigger1 = P2statetype = L

[State ΖC]
type = ChangeState
value = 250
triggerall = Random < 50
triggerall = P2bodydist X >= 0
triggerall = ctrl && (var(30)=30)
triggerall = numhelper(250) = 0
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;ѓ

[State T]
type = ChangeState
value = 240
triggerall = Random < 50
triggerall = ctrl && (var(30)=30)
triggerall = numhelper(800) = 0
trigger1 = statetype != A
trigger1 = ctrl

[State ]
type = ChangeState
value = 220
triggerall = Random < 2147483647
triggerall = Random < 500
triggerall = ctrl && (var(30)=30)
triggerAll = P2statetype != L
trigger1 = P2Bodydist X >= 150
trigger1 = P2statetype = A
trigger1 = statetype != A
trigger1 = ctrl

[State ΂̕]
type = ChangeState
value = 200
triggerall = Random < 2147483647
triggerall = Random < 500
triggerall = ctrl && (var(30)=30)
triggerAll = P2statetype != L
trigger1 = P2Bodydist X >= 150
trigger1 = P2Bodydist Y = [-65,0]
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;ڍU

[State ːi]
type = ChangeState
value = 910
triggerall = Random < 2147483647
triggerall = Random < 500
triggerall = ctrl && (var(30)=30)
triggerAll = P2statetype != L
triggerall = statetype != A
triggerAll = P2Bodydist X = [0,97]
triggerAll = P2Bodydist Y = [-57,0]
trigger1 = ctrl
trigger2 = stateno = 210 && time >= 28

[State ]]
type = ChangeState
value = 210
triggerall = Random < 2147483647
triggerall = Random < 500
triggerall = ctrl && (var(30)=30)
triggerAll = P2statetype != L
triggerAll = statetype != A
triggerAll = P2Bodydist X = [0,150]
triggerAll = P2Bodydist Y = [-57,0]
trigger1 = ctrl
trigger2 = stateno = 210 && time >= 28

;---------------------------------------------------------------------------
;lq

[State Q[Wߌp]
type = ChangeState
value = 195
triggerall = Random < 2147483647
triggerall = ctrl && (var(30)=30)
triggerAll = Power < 3000
triggerAll = statetype != A
triggerAll = ctrl
triggerAll = !inguarddist
triggerAll = prevstateno = 195
trigger1 = P2statetype = L
trigger2 = Life > 1100

[State Q[W]
type = ChangeState
value = 195
triggerall = Random < 2147483647
triggerall = ctrl && (var(30)=30)
triggerAll = Power < 3000
triggerAll = statetype != A
triggerAll = ctrl
triggerAll = !inguarddist
trigger1 = P2statetype = L;肪|Ă錄ɂ
trigger2 = Life > 1100;    ]Tɂ
trigger3 = Power >= 1500;  3000ڎw

[State ]
type = ChangeState
value = 199
triggerall = Random < 500
triggerall = var(30) != 30
triggerall = ctrl && (var(30)=30)
trigger1 = statetype != A
trigger1 = ctrl
trigger1 = !inguarddist

;==앗AIpXe[g=========================================================================

;---------------------------------------------------------------------------
[State nk]
type = ChangeState
value = 230
triggerall = var(32) = 0
triggerall = var(31) = 1
trigger1 = statetype != A
trigger1 = ctrl
;---------------------------------------------------------------------------
[State T]
type = ChangeState
value = 240
triggerall = var(32) = 1
triggerall = var(31) = 1
triggerall = numhelper(800) = 0
trigger1 = statetype != A
trigger1 = ctrl
;---------------------------------------------------------------------------
[State ΖC]
type = ChangeState
value = 250
triggerall = var(32) = 2
triggerall = var(31) = 1
triggerall = numhelper(250) = 0
trigger1 = statetype != A
trigger1 = ctrl
;---------------------------------------------------------------------------
[State tA]
type = ChangeState
value = 253
triggerall = var(32) = 3
triggerall = var(31) = 1
triggerall = numhelper(254) = 0
trigger1 = statetype != A
trigger1 = ctrl
;---------------------------------------------------------------------------
;^bN
[State -1, Stand Light Punch]
type = ChangeState
value = 910
triggerall = var(32) = 4
triggerall = var(31) = 1
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 210 && time >= 28
trigger3 = stateno = 910 && time >= 22
;---------------------------------------------------------------------------
;t@CA
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = var(32) = 5
triggerall = var(31) = 1
trigger1 = statetype != A
trigger1 = ctrl
;---------------------------------------------------------------------------
;t@CA 
[State -1, Stand Light Punch]
type = ChangeState
value = 202
triggerall = var(32) <= 4
triggerall = var(31) = 1
trigger1 = statetype = A
trigger1 = ctrl
;---------------------------------------------------------------------------
;Q[W
[State -1, Stand Light Punch]
type = ChangeState
value = 195
triggerall = var(32) = 6
triggerall = var(31) = 1
trigger1 = Power < 3000
trigger1 = statetype != A
trigger1 = ctrl
;---------------------------------------------------------------------------
;Xs
[State -1, Stand Light Punch]
type = ChangeState
value = 210
triggerall = var(32) = 7
triggerall = var(31) = 1
triggerAll = statetype != A
trigger1 = ctrl
trigger2 = stateno = 910 && time >= 22
trigger3 = stateno = 210 && time >= 28
;---------------------------------------------------------------------------
;
[State -1, Stand Light Punch]
type = ChangeState
value = 220
triggerall = var(32) = 8
triggerall = var(31) = 1
trigger1 = statetype != A
trigger1 = ctrl
;===========================================================================
;Z
;===========================================================================
;[U[
[State -1, Stand Light Punch]
type = ChangeState
value = 1000
triggerall = var(30) != 30
triggerall = command = "a"
triggerall = command = "x"
triggerall = power >= 3000
trigger1 = statetype != A
trigger1 = ctrl
;---------------------------------------------------------------------------
;
[State -1, Stand Light Punch]
type = ChangeState
value = 1011
triggerall = var(30) != 30
triggerall = command = "a"
triggerall = command = "c"
triggerall = power >= 2000
trigger1 = statetype != A
trigger1 = ctrl
;---------------------------------------------------------------------------
;啬
[State -1, Stand Light Punch]
type = ChangeState
value = 1010
triggerall = var(30) != 30
triggerall = command = "a"
triggerall = command = "b"
triggerall = power >= 1000
trigger1 = statetype != A
trigger1 = ctrl
;---------------------------------------------------------------------------
[State nk]
type = ChangeState
value = 230
triggerall = var(30) != 30
triggerall = command = "a"
triggerall = command = "holdback"
trigger1 = statetype != A
trigger1 = ctrl
;---------------------------------------------------------------------------
[State T]
type = ChangeState
value = 240
triggerall = var(30) != 30
triggerall = command = "b"
triggerall = command = "holdback"
triggerall = numhelper(800) = 0
trigger1 = statetype != A
trigger1 = ctrl
;---------------------------------------------------------------------------
[State ΖC]
type = ChangeState
value = 250
triggerall = var(30) != 30
triggerall = command = "c"
triggerall = command = "holdback"
triggerall = numhelper(250) = 0
trigger1 = statetype != A
trigger1 = ctrl
;---------------------------------------------------------------------------
[State tA]
type = ChangeState
value = 253
triggerall = var(30) != 30
triggerall = command = "x"
triggerall = command = "holdback"
triggerall = numhelper(254) = 0
trigger1 = statetype != A
trigger1 = ctrl
;---------------------------------------------------------------------------
;^bN
[State -1, Stand Light Punch]
type = ChangeState
value = 910
triggerall = var(30) != 30
triggerall = command = "a"
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = 210 && time >= 28
trigger3 = stateno = 910 && time >= 22
;---------------------------------------------------------------------------
;t@CA
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = var(30) != 30
triggerall = command = "b"
trigger1 = statetype != A
trigger1 = ctrl
;---------------------------------------------------------------------------
;t@CA 
[State -1, Stand Light Punch]
type = ChangeState
value = 202
triggerall = var(30) != 30
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl
;---------------------------------------------------------------------------
;Q[W
[State -1, Stand Light Punch]
type = ChangeState
value = 195
triggerall = var(30) != 30
triggerall = command = "c"
trigger1 = Power < 3000
trigger1 = statetype != A
trigger1 = ctrl
;---------------------------------------------------------------------------
;Xs
[State -1, Stand Light Punch]
type = ChangeState
value = 210
triggerall = var(30) != 30
triggerall = command = "x"
triggerAll = statetype != A
trigger1 = ctrl
trigger2 = stateno = 910 && time >= 22
trigger3 = stateno = 210 && time >= 28
;---------------------------------------------------------------------------
;
[State -1, Stand Light Punch]
type = ChangeState
value = 220
triggerall = var(30) != 30
triggerall = command = "y"
trigger1 = statetype != A
trigger1 = ctrl
;---------------------------------------------------------------------------
;
[State -1, Stand Light Punch]
type = ChangeState
value = 199
triggerall = var(30) != 30
triggerall = command = "z"
trigger1 = statetype != A
trigger1 = ctrl
;------------------------------------------------------------------------------
;==============================================================================
; ړ֘A
;==============================================================================
;------------------------------------------------------------------------------

[State -1, ]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl

[State -1, obNXebv]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl

;==ʏAIpXe[g=========================================================================

[State -1,2]
type       = Varset
triggerall = var(30) != 30
triggerall = var(31) != 1
trigger1 = (command = "AI-000") || (command = "AI-011")
trigger2 = (command = "AI-001") || (command = "AI-012")
trigger3 = (command = "AI-002") || (command = "AI-013")
trigger4 = (command = "AI-003") || (command = "AI-014")
trigger5 = (command = "AI-004") || (command = "AI-015")
trigger6 = (command = "AI-005") || (command = "AI-016")
trigger7 = (command = "AI-006") || (command = "AI-017")
trigger8 = (command = "AI-007") || (command = "AI-018")
trigger9 = (command = "AI-008") || (command = "AI-019")
trigger10= (command = "AI-009") || (command = "AI-020")
trigger11= (command = "AI-010") || (command = "AI-021")
trigger12 = (command = "AI-022") || (command = "AI-023")
trigger13 = (command = "AI-024") || (command = "AI-025")
trigger14 = (command = "AI-026") || (command = "AI-027")
trigger15 = (command = "AI-028") || (command = "AI-029")
trigger16 = (command = "AI-030") || (command = "AI-031")
trigger17 = (command = "AI-032") || (command = "AI-033")
trigger18 = (command = "AI-034") || (command = "AI-035")
trigger19 = (command = "AI-036") || (command = "AI-037")
trigger20 = (command = "AI-038") || (command = "AI-039")
trigger21 = (command = "AI-040") || (command = "AI-041")
trigger22 = (command = "AI-042") || (command = "AI-043")
trigger23 = (command = "AI-044") || (command = "AI-045")
trigger24 = (command = "AI-046") || (command = "AI-047")
trigger25 = (command = "AI-048") || (command = "AI-049")
trigger26 = (command = "AI-050") || (command = "AI-051")
trigger27 = (command = "AI-052") || (command = "AI-053")
trigger28 = (command = "AI-054") || (command = "AI-055")
trigger29 = (command = "AI-056") || (command = "AI-057")
trigger30 = (command = "AI-058") || (command = "AI-059")
trigger31 = (command = "AI-060") || (command = "AI-061")
trigger32 = (command = "AI-062") || (command = "AI-063")
trigger33 = (command = "AI-064") || (command = "AI-065")
trigger34 = (command = "AI-066") || (command = "AI-067")
trigger35 = (command = "AI-068") || (command = "AI-069")
trigger36 = (command = "AI-070") || (command = "AI-071")
trigger37 = (command = "AI-072") || (command = "AI-073")
trigger38 = (command = "AI-074") || (command = "AI-075")
trigger39 = (command = "AI-076") || (command = "AI-077")
trigger40 = (command = "AI-078") || (command = "AI-079")
trigger41 = (command = "AI-080") || (command = "AI-081")
trigger42 = (command = "AI-082") || (command = "AI-083")
trigger43 = (command = "AI-084") || (command = "AI-085")
trigger44 = (command = "AI-086") || (command = "AI-087")
trigger45 = (command = "AI-088") || (command = "AI-089")
trigger46 = (command = "AI-090") || (command = "AI-091")
trigger47 = (command = "AI-092") || (command = "AI-093")
trigger48 = (command = "AI-094") || (command = "AI-095")
trigger49 = (command = "AI-096") || (command = "AI-097")
trigger50 = (command = "AI-098") || (command = "AI-099")
trigger51 = IsHomeTeam = 1
trigger51 = TeamSide = 2
;trigger52  = 1;u;vOƏ펞N
v          = 30
value      = 30


;==_AIpXe[g=========================================================================

[State _s]
type       = Varset
triggerAll = var(31) != 1
triggerAll = 0;[;tƋN
trigger1 = (command = "AI-000") || (command = "AI-011")
trigger2 = (command = "AI-001") || (command = "AI-012")
trigger3 = (command = "AI-002") || (command = "AI-013")
trigger4 = (command = "AI-003") || (command = "AI-014")
trigger5 = (command = "AI-004") || (command = "AI-015")
trigger6 = (command = "AI-005") || (command = "AI-016")
trigger7 = (command = "AI-006") || (command = "AI-017")
trigger8 = (command = "AI-007") || (command = "AI-018")
trigger9 = (command = "AI-008") || (command = "AI-019")
trigger10= (command = "AI-009") || (command = "AI-020")
trigger11= (command = "AI-010") || (command = "AI-021")
trigger12 = (command = "AI-022") || (command = "AI-023")
trigger13 = (command = "AI-024") || (command = "AI-025")
trigger14 = (command = "AI-026") || (command = "AI-027")
trigger15 = (command = "AI-028") || (command = "AI-029")
trigger16 = (command = "AI-030") || (command = "AI-031")
trigger17 = (command = "AI-032") || (command = "AI-033")
trigger18 = (command = "AI-034") || (command = "AI-035")
trigger19 = (command = "AI-036") || (command = "AI-037")
trigger20 = (command = "AI-038") || (command = "AI-039")
trigger21 = (command = "AI-040") || (command = "AI-041")
trigger22 = (command = "AI-042") || (command = "AI-043")
trigger23 = (command = "AI-044") || (command = "AI-045")
trigger24 = (command = "AI-046") || (command = "AI-047")
trigger25 = (command = "AI-048") || (command = "AI-049")
trigger26 = (command = "AI-050") || (command = "AI-051")
trigger27 = (command = "AI-052") || (command = "AI-053")
trigger28 = (command = "AI-054") || (command = "AI-055")
trigger29 = (command = "AI-056") || (command = "AI-057")
trigger30 = (command = "AI-058") || (command = "AI-059")
trigger31 = (command = "AI-060") || (command = "AI-061")
trigger32 = (command = "AI-062") || (command = "AI-063")
trigger33 = (command = "AI-064") || (command = "AI-065")
trigger34 = (command = "AI-066") || (command = "AI-067")
trigger35 = (command = "AI-068") || (command = "AI-069")
trigger36 = (command = "AI-070") || (command = "AI-071")
trigger37 = (command = "AI-072") || (command = "AI-073")
trigger38 = (command = "AI-074") || (command = "AI-075")
trigger39 = (command = "AI-076") || (command = "AI-077")
trigger40 = (command = "AI-078") || (command = "AI-079")
trigger41 = (command = "AI-080") || (command = "AI-081")
trigger42 = (command = "AI-082") || (command = "AI-083")
trigger43 = (command = "AI-084") || (command = "AI-085")
trigger44 = (command = "AI-086") || (command = "AI-087")
trigger45 = (command = "AI-088") || (command = "AI-089")
trigger46 = (command = "AI-090") || (command = "AI-091")
trigger47 = (command = "AI-092") || (command = "AI-093")
trigger48 = (command = "AI-094") || (command = "AI-095")
trigger49 = (command = "AI-096") || (command = "AI-097")
trigger50 = (command = "AI-098") || (command = "AI-099")
trigger51 = IsHomeTeam = 1
trigger51 = TeamSide = 2
;trigger52  = 1;u;vOƏ펞N
v          = 31
value      = 0

[State -1,2]
type       = Varset
trigger1 = var(31) = 1
v          = 32
value      = Random%9

;AI I (jnA`hXCb`nee)
[State -1,2]
type=VarSet
trigger1   = Roundstate >= 3
v          = 30
value      = 0
